@@ -123,15 +123,6 @@ def error(msg, *args, **kwargs):
         util._logger.error(msg, *args, **kwargs)
 
 
-def safe_apply_callback(fun, *args):
-    if fun:
-        try:
-            fun(*args)
-        except Exception, exc:
-            error("Pool callback raised exception: %r", exc,
-                  exc_info=True)
-
-
 def stop_if_not_current(thread, timeout=None):
     if thread is not threading.currentThread():
         thread.stop(timeout)
@@ -956,9 +947,9 @@ class Pool(object):
                 debug('Supervisor: worked %d joined', i)
                 cleaned[worker.pid] = worker
                 exitcodes[worker.pid] = worker.exitcode
-                if -worker.exitcode not in (EX_OK, EX_RECYCLE):
+                if worker.exitcode not in (EX_OK, EX_RECYCLE):
                     error('Process %r pid:%r exited with exitcode %r' % (
-                        worker.name, worker.pid, -worker.exitcode))
+                        worker.name, worker.pid, worker.exitcode))
                 del self._pool[i]
                 del self._poolctrl[worker.pid]
         if cleaned:
@@ -1172,7 +1163,8 @@ class Pool(object):
     def apply_async(self, func, args=(), kwds={},
                     callback=None, error_callback=None, accept_callback=None,
                     timeout_callback=None, waitforslot=None,
-                    soft_timeout=None, timeout=None, lost_worker_timeout=None):
+                    soft_timeout=None, timeout=None, lost_worker_timeout=None,
+                    callbacks_propagate=()):
         '''
         Asynchronous equivalent of `apply()` method.
 
@@ -1209,6 +1201,7 @@ class Pool(object):
                 error_callback, soft_timeout, timeout, lost_worker_timeout,
                 on_timeout_set=self.on_timeout_set,
                 on_timeout_cancel=self.on_timeout_cancel,
+                callbacks_propagate=callbacks_propagate,
             )
             if timeout or soft_timeout:
                 # start the timeout handler thread when required.
@@ -1373,7 +1366,8 @@ class ApplyResult(object):
     def __init__(self, cache, callback, accept_callback=None,
                  timeout_callback=None, error_callback=None, soft_timeout=None,
                  timeout=None, lost_worker_timeout=LOST_WORKER_TIMEOUT,
-                 on_timeout_set=None, on_timeout_cancel=None):
+                 on_timeout_set=None, on_timeout_cancel=None,
+                 callbacks_propagate=()):
         self._mutex = threading.Lock()
         self._event = threading.Event()
         self._job = job_counter.next()
@@ -1387,6 +1381,7 @@ class ApplyResult(object):
         self._lost_worker_timeout = lost_worker_timeout
         self._on_timeout_set = on_timeout_set
         self._on_timeout_cancel = on_timeout_cancel
+        self._callbacks_propagate = callbacks_propagate or ()
 
         self._accepted = False
         self._worker_pid = None
@@ -1418,6 +1413,16 @@ class ApplyResult(object):
         else:
             raise self._value.exception
 
+    def safe_apply_callback(self, fun, *args):
+        if fun:
+            try:
+                fun(*args)
+            except self._callbacks_propagate:
+                raise
+            except Exception, exc:
+                error("Pool callback raised exception: %r", exc,
+                      exc_info=True)
+
     def _set(self, i, obj):
         with self._mutex:
             if self._on_timeout_cancel:
@@ -1429,11 +1434,11 @@ class ApplyResult(object):
 
             # apply callbacks last
             if self._callback and self._success:
-                safe_apply_callback(
+                self.safe_apply_callback(
                     self._callback, self._value)
             if (self._value is not None and
                     self._error_callback and not self._success):
-                safe_apply_callback(
+                self.safe_apply_callback(
                     self._error_callback, self._value)
 
     def _ack(self, i, time_accepted, pid):
@@ -1446,7 +1451,7 @@ class ApplyResult(object):
             if self._on_timeout_set:
                 self._on_timeout_set(self, self._soft_timeout, self._timeout)
             if self._accept_callback:
-                safe_apply_callback(
+                self.safe_apply_callback(
                     self._accept_callback, pid, time_accepted)
 
 #
